@@ -40,7 +40,7 @@ use File::Spec                      ();
 use SDL::Tutorial::3DWorld::Texture ();
 use OpenGL;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =pod
 
@@ -165,46 +165,46 @@ sub display {
 	# Draw the north face
 	$self->{north}->display;
 	glBegin( GL_QUADS );
-	glTexCoord2f( 0, 0 ); glVertex3f( -501,  501,  500 ); # Top Left
-	glTexCoord2f( 1, 0 ); glVertex3f(  501,  501,  500 ); # Top Right
-	glTexCoord2f( 1, 1 ); glVertex3f(  501, -501,  500 ); # Bottom Right
-	glTexCoord2f( 0, 1 ); glVertex3f( -501, -501,  500 ); # Bottom Left
+	glTexCoord2f( 0, 0 ); glVertex3f( -501,  501, -500 ); # Top Left
+	glTexCoord2f( 1, 0 ); glVertex3f(  501,  501, -500 ); # Top Right
+	glTexCoord2f( 1, 1 ); glVertex3f(  501, -501, -500 ); # Bottom Right
+	glTexCoord2f( 0, 1 ); glVertex3f( -501, -501, -500 ); # Bottom Left
 	glEnd();
 
 	# Draw the south face 
 	$self->{south}->display;
 	glBegin( GL_QUADS );
-	glTexCoord2f( 0, 0 ); glVertex3f(  501,  501, -500 ); # Top Left
-	glTexCoord2f( 1, 0 ); glVertex3f( -501,  501, -500 ); # Top Right
-	glTexCoord2f( 1, 1 ); glVertex3f( -501, -501, -500 ); # Bottom Right
-	glTexCoord2f( 0, 1 ); glVertex3f(  501, -501, -500 ); # Bottom Left
+	glTexCoord2f( 0, 0 ); glVertex3f(  501,  501,  500 ); # Top Left
+	glTexCoord2f( 1, 0 ); glVertex3f( -501,  501,  500 ); # Top Right
+	glTexCoord2f( 1, 1 ); glVertex3f( -501, -501,  500 ); # Bottom Right
+	glTexCoord2f( 0, 1 ); glVertex3f(  501, -501,  500 ); # Bottom Left
 	glEnd();
 
 	# Draw the east face
 	$self->{east}->display;
 	glBegin( GL_QUADS );
-	glTexCoord2f( 0, 0 ); glVertex3f(  500,  501,  501 ); # Top Left
-	glTexCoord2f( 1, 0 ); glVertex3f(  500,  501, -501 ); # Top Right
-	glTexCoord2f( 1, 1 ); glVertex3f(  500, -501, -501 ); # Bottom Right
-	glTexCoord2f( 0, 1 ); glVertex3f(  500, -501,  501 ); # Bottom Left
+	glTexCoord2f( 0, 0 ); glVertex3f(  500,  501, -501 ); # Top Left
+	glTexCoord2f( 1, 0 ); glVertex3f(  500,  501,  501 ); # Top Right
+	glTexCoord2f( 1, 1 ); glVertex3f(  500, -501,  501 ); # Bottom Right
+	glTexCoord2f( 0, 1 ); glVertex3f(  500, -501, -501 ); # Bottom Left
 	glEnd();
 
 	# Draw the west face
 	$self->{west}->display;
 	glBegin( GL_QUADS );
-	glTexCoord2f( 0, 0 ); glVertex3f( -500,  501, -501 ); # Top Left
-	glTexCoord2f( 1, 0 ); glVertex3f( -500,  501,  501 ); # Top Right
-	glTexCoord2f( 1, 1 ); glVertex3f( -500, -501,  501 ); # Bottom Right
-	glTexCoord2f( 0, 1 ); glVertex3f( -500, -501, -501 ); # Bottom Left
+	glTexCoord2f( 0, 0 ); glVertex3f( -500,  501,  501 ); # Top Left
+	glTexCoord2f( 1, 0 ); glVertex3f( -500,  501, -501 ); # Top Right
+	glTexCoord2f( 1, 1 ); glVertex3f( -500, -501, -501 ); # Bottom Right
+	glTexCoord2f( 0, 1 ); glVertex3f( -500, -501,  501 ); # Bottom Left
 	glEnd();
 
 	# Draw the ceiling face
 	$self->{up}->display;
 	glBegin( GL_QUADS );
-	glTexCoord2f( 0, 0 ); glVertex3f( -501,  500, -501 ); # Top Left
-	glTexCoord2f( 1, 0 ); glVertex3f(  501,  500, -501 ); # Top Right
-	glTexCoord2f( 1, 1 ); glVertex3f(  501,  500,  501 ); # Bottom Right
-	glTexCoord2f( 0, 1 ); glVertex3f( -501,  500,  501 ); # Bottom Left
+	glTexCoord2f( 0, 0 ); glVertex3f( -501,  500,  501 ); # Top Left
+	glTexCoord2f( 1, 0 ); glVertex3f(  501,  500,  501 ); # Top Right
+	glTexCoord2f( 1, 1 ); glVertex3f(  501,  500, -501 ); # Bottom Right
+	glTexCoord2f( 0, 1 ); glVertex3f( -501,  500, -501 ); # Bottom Left
 	glEnd();
 
 	# Draw the optional floor
